==> libqt4-appdownloader-comm_0.0.3.tar.gz: libqt4-appdownloader-comm-0.0.3/src/MaemoApplication.cpp <==
#include "MaemoApplication.h"

MaemoApplication::MaemoApplication () {
    this->name = "";
    this->uid = "";
    this->rating = "";
    this->downloads = "";
    this->comments = "";
    this->version = "";
    this->title = "";
    this->preview="";
}
MaemoApplication::MaemoApplication (QString _name,
                  QString _uid,
                  QString _title,
                  QString _rating,
                  QString _downloads,
                  QString _comments,
                  QString _version,
                  QString _pre
                  ) {
    this->name = _name;
    this->uid = _uid;
    this->title = _title;
    this->rating = _rating;
    this->downloads = _downloads;
    this->comments = _comments;
    this->version = _version;
    this->preview = _pre;

}

MaemoApplication::MaemoApplication (QString _uid) {
    this->uid = _uid;
    this->name = "";
    this->rating = "";
    this->downloads = "";
    this->comments = "";
    this->version = "";
    this->title = "";
}

void MaemoApplication::setUid (QString _uid) {
    this->uid = _uid;
}

void MaemoApplication::setTitle (QString _title) {
    this->title = _title;
}

void MaemoApplication::setName (QString _name) {
    this->name = _name;
}

void MaemoApplication::setVersion (QString _version) {
    this->version = _version;
}

void MaemoApplication::setDownloads (QString _downloads) {
    this->downloads = _downloads;
}

 void MaemoApplication::setRating (QString _rating) {
    this->rating = _rating;
}

void MaemoApplication::setComments (QString _comments) {
    this->comments = _comments;
}

void MaemoApplication::setPreview (QString _pre) {
    this->preview = _pre;
}


QString MaemoApplication::getComments () {
    return this->comments;
}

QString MaemoApplication::getUid () {
    return uid;
}
QString MaemoApplication::getName () {
    return name;
}
QString MaemoApplication::getTitle () {
    return title;
}

QString MaemoApplication::getVersion () {
    return this->version;
}

QString MaemoApplication::getRating () {
    return rating;
}

QString MaemoApplication::getDownloads () {
    return this->downloads;
}

QString MaemoApplication::getPreview () {
    return this->preview;
}

QString MaemoApplication::toString () {
    return "Name: " + name + "\ntitle: " + title + "\nuid: " + uid;
}

==> libqt4-appdownloader-comm_0.2.tar.gz: libqt4-appdownloader-comm-0.2/src/MaemoApplication.cpp <==
#include "MaemoApplication.h"

MaemoApplication::MaemoApplication () {
    this->name = "";
    this->uid = "";
    this->rating = "";
    this->downloads = "";
    this->comments = "";
    this->version = "";
    this->title = "";
    this->preview="";
}
MaemoApplication::MaemoApplication (QString _name,
                  QString _uid,
                  QString _title,
                  QString _rating,
                  QString _downloads,
                  QString _comments,
                  QString _version,
                  QString _pre,
                  QString _bpre
                  ) {
    this->name = _name;
    this->uid = _uid;
    this->title = _title;
    this->rating = _rating;
    this->downloads = _downloads;
    this->comments = _comments;
    this->version = _version;
    this->preview = _pre;
    this->bigPreview = _bpre;
}

MaemoApplication::MaemoApplication (QString _uid) {
    this->uid = _uid;
    this->name = "";
    this->rating = "";
    this->downloads = "";
    this->comments = "";
    this->version = "";
    this->title = "";
    this->preview ="";
    this->bigPreview="";
}

void MaemoApplication::setBigPreview(QString _bpre) {
    bigPreview =_bpre;
}

void MaemoApplication::setUid (QString _uid) {
    this->uid = _uid;
}

void MaemoApplication::setTitle (QString _title) {
    this->title = _title;
}

void MaemoApplication::setName (QString _name) {
    this->name = _name;
}

void MaemoApplication::setVersion (QString _version) {
    this->version = _version;
}

void MaemoApplication::setDownloads (QString _downloads) {
    this->downloads = _downloads;
}

 void MaemoApplication::setRating (QString _rating) {
    this->rating = _rating;
}

void MaemoApplication::setComments (QString _comments) {
    this->comments = _comments;
}

void MaemoApplication::setPreview (QString _pre) {
    this->preview = _pre;
}

QString MaemoApplication::getBigPreview() {
    return this->bigPreview;
}

QString MaemoApplication::getComments () {
    return this->comments;
}

QString MaemoApplication::getUid () {
    return uid;
}
QString MaemoApplication::getName () {
    return name;
}
QString MaemoApplication::getTitle () {
    return title;
}

QString MaemoApplication::getVersion () {
    return this->version;
}

QString MaemoApplication::getRating () {
    return rating;
}

QString MaemoApplication::getDownloads () {
    return this->downloads;
}

QString MaemoApplication::getPreview () {
    return this->preview;
}

QString MaemoApplication::toString () {
    return "Name: " + name + "\ntitle: " + title + "\nuid: " + uid;
}
